// Created By Lucas Pekel (http://www.lucaspekel.nl) on 13-09-2011
// Last edited By Lucas Pekel on 13-09-2011

// db error handler - prevents the rest of the transaction going ahead on failure
errorHandler = function (transaction, error) { 
	console.log(transaction);
	console.log(error); 
	return true; 
} 

// null db data handler
nullDataHandler = function (transaction, results) { } 

// Create a singleton for a single point of entry for the database.
// All database initializations and methods will be handled here.
var DB = (
	function() {
		var mydb = false;
		function DB() {
			try {
				if (!window.openDatabase) { 
					alert('not supported'); 
				} else {
					var shortName = 'AppDatabase'; 
					var version = '1.0'; 
					var displayName = 'Database for Xenoblade Chronicles data'; 
					var maxSize = 5048576; // in bytes
					mydb = openDatabase(shortName, version, displayName, maxSize); 
				}
			} catch(e) { // Error handling code goes here. 
				if (e == INVALID_STATE_ERR) { 
					// Version number mismatch. 
					alert("Invalid database version."); 
				} else { 
					alert("Unknown error "+e+"."); 
				} 
				return;
			}
	  
			// create tables for the database
			try {
				mydb.transaction(function(transaction) {
					var query="CREATE TABLE IF NOT EXISTS `Character` (`CharacterID` int(1),`Name`varchar(6) NOT NULL,`Gender`varchar(20) NOT NULL,`Age` int(2),`Species`varchar(20) NOT NULL,`Description` TEXT ,`BTD` TEXT)";
					transaction.executeSql(query, [], nullDataHandler, errorHandler);
					
					query="CREATE TABLE IF NOT EXISTS `Gift` (`GiftID` int(3),`GiftName`varchar(20) NOT NULL,`Type`varchar(20) NOT NULL,`Area` varcahr(20))";
					transaction.executeSql(query, [], nullDataHandler, errorHandler);
					
					query="CREATE TABLE IF NOT EXISTS `CharacterGift` (`CharacterID` int(1),`GiftID`int(3) NOT NULL,`Hearts`int(1) NOT NULL)";
					transaction.executeSql(query, [], nullDataHandler, errorHandler);
					
					query="CREATE TABLE IF NOT EXISTS `Affinity` (`Character1` varchar(6) NOT NULL,`Character2` varchar(6) NOT NULL,Affinity int(1) NOT NULL)";
					transaction.executeSql(query, [], nullDataHandler, errorHandler);
					
					query="CREATE TABLE IF NOT EXISTS `HeartToHeart` (`Name` varchar(50) NOT NULL,`Character1` varchar(20) NOT NULL,`Character2` varchar(20) NOT NULL,`Affinity` int(1) NOT NULL,`Area` varchar(50) NOT NULL,`Location` varchar(50) NOT NULL,`Best` varchar(3) NOT NULL,`Worst` varchar(3) NOT NULL,`Status` INT(1) DEFAULT NULL)";
					
					//affection chart:
					// 1 = Yellow hexagon
					// 2 = Green square
					// 3 = Blue circle
					// 4 = Purple cloud
					// 5 = Red heart
					transaction.executeSql(query, [], nullDataHandler, errorHandler);
						
				});
			} catch(e) {
				alert(e.message);
				return;
			}
	  
			return {
				// execute query to select the UUID and Medewerker 
				ExecuteQuery: function(query,parseFunction) {
					try {
						mydb.transaction(function(transaction) {
							transaction.executeSql(query,[], function(transaction, results) {
								parseFunction(results);                   
							}, errorHandler);
						});
					} catch(e) {
						alert(e.message);
					}
				},
				ExecuteQueryArray: function(aQuery) {
					try {
						mydb.transaction(function(transaction) {
							for(var i in aQuery){
								transaction.executeSql(aQuery[i],[], function(transaction, results) {}, errorHandler);
							}
						});
					} catch(e) {
						alert(e.message);
					}
				},
				ExecuteQueryWithData:function(query,data,parseFunction) {
					try {
						mydb.transaction(function(transaction) {
							transaction.executeSql(query,[], function(transaction, results) {parseFunction(results,data);}, errorHandler);
						});
					} catch(e) {
						alert(e.message);
					}
				},
				//Drop all known tables to remove the content
			  	DropAllTables: function() {
					var query="SELECT name FROM (SELECT * FROM sqlite_master UNION ALL SELECT * FROM sqlite_temp_master) WHERE type='table' ORDER BY name";
					instance.ExecuteQuery(query,function(result) {
							for (var i=0; i<result.rows.length; i++) {
							var row = result.rows.item(i);
							if(row["name"] != "sqlite_sequence" && row["name"] != "__WebKitDatabaseInfoTable__") {
								var query2="DROP TABLE "+row['name']+";";
								instance.ExecuteQuery(query2,function(result){});
							}
						}
					});
				}
		};
	}
	var instance;
	return {
		GetInstance: function() {
			if (!instance) {
				instance = new DB();
				// Hide the constructor so the returned objected can't be new'd...
				instance.constructor = null;
			}
			return instance;
		}
	};
	})();


//DB.getInstance().ExecuteQuery(query, function(result){});